==> neibers-8.x-1.1.tar.gz: neibers/cbos/cabinet/src/Entity/Cabinet.php <==
<?php

namespace Drupal\cabinet\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;

/**
 * Defines the Cabinet entity.
 *
 * @ingroup cabinet
 *
 * @ContentEntityType(
 *   id = "cabinet",
 *   label = @Translation("Cabinet"),
 *   label_collection = @Translation("Cabinet"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\cabinet\CabinetListBuilder",
 *     "views_data" = "Drupal\cabinet\Entity\CabinetViewsData",
 *     "translation" = "Drupal\cabinet\CabinetTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\cabinet\Form\CabinetForm",
 *       "add" = "Drupal\cabinet\Form\CabinetForm",
 *       "edit" = "Drupal\cabinet\Form\CabinetForm",
 *       "delete" = "Drupal\cabinet\Form\CabinetDeleteForm",
 *     },
 *     "access" = "Drupal\cabinet\CabinetAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\cabinet\CabinetHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "cabinet",
 *   data_table = "cabinet_field_data",
 *   translatable = TRUE,
 *   admin_permission = "administer cabinet",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "user_id",
 *     "langcode" = "langcode",
 *     "status" = "status",
 *   },
 *   links = {
 *     "canonical" = "/cabinet/{cabinet}",
 *     "add-form" = "/cabinet/add",
 *     "edit-form" = "/cabinet/{cabinet}/edit",
 *     "delete-form" = "/cabinet/{cabinet}/delete",
 *     "collection" = "/cabinet",
 *   },
 *   field_ui_base_route = "cabinet.settings"
 * )
 */
class Cabinet extends ContentEntityBase implements CabinetInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   * TODO replace with client id.
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'user_id' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name) {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('user_id')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('user_id')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('user_id', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('user_id', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished() {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published) {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['user_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the Cabinet entity.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The name of the Cabinet entity.'))
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['size'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Size'))
      ->setDescription(t('Switch occupied seat in digit.'))
      ->setDisplayOptions('form', [
        'type' => 'radios_number',
        'weight' => 10,
        'settings' => [
          'options' => [1 => '1U', 2 => '2U', 3 => '3U', '4' => '4U'],
        ],
      ])
      ->setDisplayConfigurable('form', TRUE);

    $fields['room'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Machine Room'))
      ->setSetting('target_type', 'room')
      ->setDisplayOptions('view', [
        'type' => 'entity_reference_label',
        'weight' => 6,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 6,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the Cabinet is published.'))
      ->setDefaultValue(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'weight' => -3,
      ]);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    return $fields;
  }

}

==> neibers-8.x-3.0.tar.gz: neibers/cbos/cabinet/src/Entity/Cabinet.php <==
<?php

namespace Drupal\neibers_cabinet\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;

/**
 * Defines the Cabinet entity.
 *
 * @ingroup neibers_cabinet
 *
 * @ContentEntityType(
 *   id = "neibers_cabinet",
 *   label = @Translation("Cabinet"),
 *   label_collection = @Translation("Cabinet"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\neibers_cabinet\CabinetListBuilder",
 *     "views_data" = "Drupal\neibers_cabinet\Entity\CabinetViewsData",
 *     "translation" = "Drupal\neibers_cabinet\CabinetTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\neibers_cabinet\Form\CabinetForm",
 *       "add" = "Drupal\neibers_cabinet\Form\CabinetForm",
 *       "edit" = "Drupal\neibers_cabinet\Form\CabinetForm",
 *       "delete" = "Drupal\neibers_cabinet\Form\CabinetDeleteForm",
 *     },
 *     "access" = "Drupal\neibers_cabinet\CabinetAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\neibers_cabinet\CabinetHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "neibers_cabinet",
 *   data_table = "neibers_cabinet_field_data",
 *   translatable = TRUE,
 *   admin_permission = "administer neibers cabinet",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "user_id",
 *     "langcode" = "langcode",
 *     "status" = "status",
 *   },
 *   links = {
 *     "canonical" = "/cabinet/{neibers_cabinet}",
 *     "add-form" = "/cabinet/add",
 *     "edit-form" = "/cabinet/{neibers_cabinet}/edit",
 *     "delete-form" = "/cabinet/{neibers_cabinet}/delete",
 *     "collection" = "/cabinet",
 *   },
 *   field_ui_base_route = "neibers_cabinet.settings"
 * )
 */
class Cabinet extends ContentEntityBase implements CabinetInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   * TODO replace with client id.
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'user_id' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name) {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('user_id')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('user_id')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('user_id', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('user_id', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished() {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published) {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['user_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the Cabinet entity.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The name of the Cabinet entity.'))
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['size'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Size'))
      ->setDescription(t('Switch occupied neibers_seat in digit.'))
      ->setDisplayOptions('form', [
        'type' => 'radios_number',
        'weight' => 10,
        'settings' => [
          'options' => [1 => '1U', 2 => '2U', 3 => '3U', '4' => '4U'],
        ],
      ])
      ->setDisplayConfigurable('form', TRUE);

    $fields['room'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Room'))
      ->setSetting('target_type', 'neibers_room')
      ->setDisplayOptions('view', [
        'type' => 'entity_reference_label',
        'weight' => 6,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 6,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the Cabinet is published.'))
      ->setDefaultValue(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'weight' => -3,
      ]);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    return $fields;
  }

}
